@@ -26,7 +26,7 @@ Implementation Notes
 
 """
 
-__version__ = "2.5.18"
+__version__ = "2.5.19"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_LED_Animation.git"
 
 from adafruit_led_animation.animation import Animation
@@ -152,7 +152,11 @@ class AnimationGroup:
                         member.show()
             return result
 
-        return any(item.animate(show) for item in self._members)
+        ret = False
+        for item in self._members:
+            if item.animate(show):
+                ret = True
+        return ret
 
     @property
     def color(self):
